@@ -42,7 +42,7 @@ class ManageFiles():
         # Setting the url for the file by combining FMS API base url and the file key
         url = f"{self.fms_url}/{file_key}"
         # Setting the location of the file to be uploaded
-        file_location = os.path.join(base_path,f"{file_key}.{file_extention}")
+        file_location = os.path.join(base_path,f"{file_name}.{file_extention}")
         # Setting the header of the post request, file extension must be sent in the headers as same as the original extesion of the file
         headers = {'content-type': 'application/octet-stream',
                     'x-ext': file_extention, 'x-group': group, 'x-createdBy': created_by}
@@ -58,7 +58,7 @@ class ManageFiles():
         # Closing post request after finishing upload
         file_request.close()
         # Return success message
-        return f"File Uploaded Successfully {file_key}.{file_name}"
+        return f"File Uploaded Successfully {file_name}.{file_extention}"
         
     # This function is to delete the file locally, not from the FMS API (only for cleaning the storage\)
     def delete_file(self, file_key, ext, base_path): 
